@@ -1,6 +1,4 @@
 require("StepReg") || stop("unable to load StepReg")
 require("testthat") || stop("unable to load testthat")
 require("survival") || stop("unable to load survival")
-require("dplyr") || stop("unable to load dplyr")
-require("stringr") || stop("unable to load stringr")
 test_check("StepReg")
